@@ -28,7 +28,7 @@ has 'api_cache'   => sub {
   $self->__build_responsetypes;
 };
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $AUTOLOAD;
 
 chomp(our $user = `whoami`);
@@ -70,7 +70,7 @@ sub AUTOLOAD {
   die sprintf("Could not get response for %s %s %s", $req,  $res->code, $res->message) unless $items;
   my $responsetype = (keys %$items)[0];
 
-  if($responsetype =~ /^(activate|add|archive|assign|associate|attach|authorize|change|configure|copy|create|delete|deploy|destroy|detach|disable|disassociate|enable|error|expunge|extract|get|list|lock|migrate|query|reboot|recover|register|remove|replace|reset|resize|restart|restore|revert|revoke|scale|start|stop|suspend|update|upload)(.*)(response)$/){
+  if($responsetype =~ /^(login|activate|add|archive|assign|associate|attach|authorize|change|configure|copy|create|delete|deploy|destroy|detach|disable|disassociate|enable|error|expunge|extract|get|list|lock|migrate|query|reboot|recover|register|remove|replace|reset|resize|restart|restore|revert|revoke|scale|start|stop|suspend|update|upload)(.*)(response)$/){
     my ($otype, $oname, $oresponse) = ($1, $2, $3);
     $items->{$responsetype}{_cs} = $self unless $oname eq 'apis';
     if($oname eq 'apis'){
@@ -87,11 +87,11 @@ sub AUTOLOAD {
         } @{$items->{$responsetype}{$oname}}
       );
     } elsif($otype eq 'query'){
-      #warn Dumper 'QUERY', $responsetype, $items->{$responsetype};
       return  Mojo::Cloudstack::Base->new('Mojo::Cloudstack::AsyncJobResult', $items->{$responsetype});
-
     } elsif(exists $items->{$responsetype}{errorcode}){
       return  Mojo::Cloudstack::Base->new('Mojo::Cloudstack::Error', $items->{$responsetype});
+    } elsif($otype =~ /^log(in|out)$/){
+      return  Mojo::Cloudstack::Base->new('Mojo::Cloudstack::' . ucfirst($&), $items->{$responsetype});
     } else {
       return  Mojo::Cloudstack::Base->new('Mojo::Cloudstack::' . (exists $items->{$responsetype}{jobid}
         ? 'AsyncJobRequest'
